/********************************************************************************
** Form generated from reading UI file 'success.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SUCCESS_H
#define UI_SUCCESS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Success
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *successIcon;
    QLabel *successLbl;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Success)
    {
        if (Success->objectName().isEmpty())
            Success->setObjectName("Success");
        Success->resize(400, 300);
        verticalLayout = new QVBoxLayout(Success);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(10);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        successIcon = new QLabel(Success);
        successIcon->setObjectName("successIcon");
        successIcon->setMaximumSize(QSize(48, 48));

        horizontalLayout->addWidget(successIcon);

        successLbl = new QLabel(Success);
        successLbl->setObjectName("successLbl");
        successLbl->setTextFormat(Qt::PlainText);

        horizontalLayout->addWidget(successLbl);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(Success);

        QMetaObject::connectSlotsByName(Success);
    } // setupUi

    void retranslateUi(QWidget *Success)
    {
        successLbl->setText(QString());
        (void)Success;
    } // retranslateUi

};

namespace Ui {
    class Success: public Ui_Success {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SUCCESS_H

