// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_BLUEDEVIL_WIZARD_LOG_BLUEDEVIL_WIZARD_H
#define ECM_QLOGGINGCATEGORY_BLUEDEVIL_WIZARD_LOG_BLUEDEVIL_WIZARD_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(BLUEDEVIL_WIZARD_LOG)


#endif
